@@ -1,7 +1,7 @@
 # -*- cperl -*-
 # $Author: ddumont $
-# $Date: 2009-03-31 13:41:21 +0200 (Tue, 31 Mar 2009) $
-# $Revision: 910 $
+# $Date: 2009-06-23 14:34:38 +0200 (Tue, 23 Jun 2009) $
+# $Revision: 984 $
 
 # this file is used by test script
 
@@ -65,8 +65,10 @@
 	       std_id => {
 			  type => 'hash',
 			  index_type  => 'string',
-			  cargo_type => 'node',
-			  config_class_name => 'SlaveZ' ,
+			  cargo => {
+				    type => 'node',
+				    config_class_name => 'SlaveZ'
+				   } ,
 			 },
 	       sub_slave => { type => 'node' ,
 			      config_class_name => 'SubSlave',
@@ -97,47 +99,54 @@
 
   [
    name => 'Master',
-   permission => [ [qw/tree_macro warp/] => 'advanced'] ,
+   experience => [ [qw/tree_macro warp/] => 'advanced'] ,
    class_description => "Master description",
    level      => [ [qw/hash_a tree_macro int_v/] => 'important' ],
    element => [
 	       std_id => { type => 'hash',
 			   index_type  => 'string',
-			   cargo_type => 'node',
-			   config_class_name => 'SlaveZ' ,
+			   cargo => { type => 'node',
+				      config_class_name => 'SlaveZ'
+				    } ,
 			 },
 	       [qw/lista listb/] => { type => 'list',
-				      cargo_type => 'leaf',
-				      cargo_args => {value_type => 'uniline'},
+				      cargo => { type => 'leaf',
+						 value_type => 'uniline'
+					       },
 				    },
 	       [qw/hash_a hash_b/] => { type => 'hash',
 			  index_type => 'string',
-			  cargo_type => 'leaf',
-			  cargo_args => {value_type => 'uniline'},
+			  cargo => { type => 'leaf',
+				     value_type => 'uniline'
+				   },
 			},
 	       ordered_hash => { type => 'hash',
 				 index_type => 'string',
 				 ordered => 1 ,
-				 cargo_type => 'leaf',
-				 cargo_args => {value_type => 'uniline'},
+				 cargo => { type => 'leaf',
+					    value_type => 'uniline'
+					  },
 			       },
 	       ordered_hash_of_mandatory => { type => 'hash',
 				 index_type => 'string',
 				 ordered => 1 ,
-				 cargo_type => 'leaf',
-				 cargo_args => {value_type => 'uniline',
-						mandatory => 1,
-					       },
+				 cargo => { type => 'leaf',
+					    value_type => 'uniline',
+					    mandatory => 1,
+					  },
 			       },
-	       ordered_hash_of_nodes => { type => 'hash',
-					  index_type => 'string',
-					  ordered => 1 ,
-					  cargo_type => 'node',
-					  config_class_name => 'SlaveZ'
-					},
+	       'ordered_hash_of_nodes'
+	       => { type => 'hash',
+		    index_type => 'string',
+		    ordered => 1 ,
+		    cargo => { type => 'node',
+			       config_class_name => 'SlaveZ'
+			     },
+		  },
 	       olist => { type => 'list',
-			  cargo_type => 'node',
-			  config_class_name => 'SlaveZ' ,
+			  cargo => { type => 'node',
+				     config_class_name => 'SlaveZ' ,
+				   },
 			},
 	       enum_list => { type => 'list',
 			      cargo => { type => 'leaf',
@@ -195,9 +204,9 @@
 			  min        => 5,
 			  max        => 15
 			},
-	       built_in_default => { type => 'leaf',
+	       upstream_default => { type => 'leaf',
 			  value_type => 'integer',
-			  built_in    => '10',
+			  upstream_default  => '10',
 			},
 	       my_plain_check_list => { type => 'check_list',
 					choice => ['AA' .. 'AE'],
